@@ -39,7 +39,7 @@ class LoggerWrapper(threading.Thread):
 
         # create the pipe and reader
         self.fd_read, self.fd_write = os.pipe()
-        self.reader = os.fdopen(self.fd_read)
+        self.reader = os.fdopen(self.fd_read, encoding="utf-8")
 
         self.start()
 
@@ -82,8 +82,10 @@ def log_subprocessor(
             stdout=outstream.fileno(),
             stderr=subprocess.STDOUT,
         )
-    except subprocess.CalledProcessError:
-        raise BuildError(f"Call command {cmd} return non-zero status.")
+    except subprocess.CalledProcessError as e:
+        raise BuildError(
+            f"Call command {cmd} return non-zero status({e.returncode})."
+        ) from None
     finally:
         outstream.stop()
 
@@ -128,14 +130,18 @@ class _Prefix:
 class EnvBuilder:
     """A simple PEP 517 builder for an isolated environment"""
 
-    _shared_envs: dict[int, str] = {}
-    _overlay_envs: dict[str, str] = {}
-
     DEFAULT_BACKEND = {
         "build-backend": "setuptools.build_meta:__legacy__",
         "requires": ["setuptools >= 40.8.0", "wheel"],
     }
 
+    _shared_envs: dict[int, str] = {}
+    _overlay_envs: dict[str, str] = {}
+
+    if TYPE_CHECKING:
+        _hook: Pep517HookCaller
+        _requires: list[str]
+
     @classmethod
     def get_shared_env(cls, key: int) -> str:
         if key in cls._shared_envs:
@@ -153,9 +159,13 @@ class EnvBuilder:
         return cls._overlay_envs[key]
 
     def __init__(self, src_dir: str | Path, environment: Environment) -> None:
+        """If isolated is True(default), the builder will set up a *clean* environment.
+        Otherwise, the environment of the host Python will be used.
+        """
         self._env = environment
-        self.executable = self._env.interpreter.executable
+        self.executable = self._env.interpreter.executable.as_posix()
         self.src_dir = src_dir
+        self.isolated = environment.project.config["build_isolation"]
         logger.debug("Preparing isolated env for PEP 517 build...")
         try:
             with open(os.path.join(src_dir, "pyproject.toml"), "rb") as f:
@@ -164,40 +174,56 @@ class EnvBuilder:
             spec = {}
         except Exception as e:
             raise BuildError(e) from e
-        self._build_system = spec.get("build-system", self.DEFAULT_BACKEND)
+        build_system = spec.get("build-system", self.DEFAULT_BACKEND)
 
-        if "build-backend" not in self._build_system:
-            self._build_system["build-backend"] = self.DEFAULT_BACKEND["build-backend"]
+        if "build-backend" not in build_system:
+            build_system["build-backend"] = self.DEFAULT_BACKEND["build-backend"]
 
-        if "requires" not in self._build_system:
+        if "requires" not in build_system:
             raise BuildError("Missing 'build-system.requires' in pyproject.toml")
 
-        self._backend = self._build_system["build-backend"]
-
+        self.init_build_system(build_system)
         self._prefix = _Prefix(
             self.executable,
-            shared=self.get_shared_env(hash(frozenset(self._build_system["requires"]))),
+            shared=self.get_shared_env(hash(frozenset(self._requires))),
             overlay=self.get_overlay_env(os.path.normcase(self.src_dir).rstrip("\\/")),
         )
 
+    def init_build_system(self, build_system: dict[str, Any]) -> None:
+        """Initialize the build system and requires list from the PEP 517 spec"""
         self._hook = Pep517HookCaller(
-            src_dir,
-            self._backend,
-            backend_path=self._build_system.get("backend-path"),
+            self.src_dir,
+            build_system["build-backend"],
+            backend_path=build_system.get("backend-path"),
             runner=self.subprocess_runner,
             python_executable=self.executable,
         )
+        self._requires = build_system["requires"]
+        if build_system["build-backend"].startswith("setuptools"):
+            self.ensure_setup_py()
 
     @property
     def _env_vars(self) -> dict[str, str]:
         paths = self._prefix.bin_dirs
         if "PATH" in os.environ:
             paths.append(os.getenv("PATH", ""))
-        return {
-            "PYTHONPATH": self._prefix.site_dir,
-            "PATH": os.pathsep.join(paths),
-            "PYTHONNOUSERSITE": "1",
-        }
+        env = {"PATH": os.pathsep.join(paths)}
+        if self.isolated:
+            env.update(
+                {
+                    "PYTHONPATH": self._prefix.site_dir,
+                    "PYTHONNOUSERSITE": "1",
+                }
+            )
+        else:
+            project_libs = self._env.get_paths()["purelib"]
+            pythonpath = self._prefix.lib_dirs + [project_libs]
+            if "PYTHONPATH" in os.environ:
+                pythonpath.append(os.getenv("PYTHONPATH", ""))
+            env.update(
+                PYTHONPATH=os.pathsep.join(pythonpath),
+            )
+        return env
 
     def subprocess_runner(
         self,
@@ -241,6 +267,7 @@ class EnvBuilder:
             req_file.close()
             cmd = self._env.pip_command + [
                 "install",
+                "--isolated",
                 "--ignore-installed",
                 "--prefix",
                 path,
@@ -261,7 +288,7 @@ class EnvBuilder:
         self, out_dir: str, config_settings: Mapping[str, Any] | None = None
     ) -> str:
         """Prepare metadata and store in the out_dir. Some backends doesn't provide that API,
-        in that case the metadata will be retreived from the built result.
+        in that case the metadata will be retrieved from the built result.
         """
         raise NotImplementedError("Should be implemented in subclass")
 
@@ -275,3 +302,17 @@ class EnvBuilder:
         return the absolute path of the built result.
         """
         raise NotImplementedError("Should be implemented in subclass")
+
+    def ensure_setup_py(self) -> str:
+        from pdm.pep517.base import Builder
+        from pdm.project.metadata import MutableMetadata
+
+        builder = Builder(self.src_dir)
+        if os.path.exists(os.path.join(self.src_dir, "pyproject.toml")):
+            try:
+                builder._meta = MutableMetadata(
+                    os.path.join(self.src_dir, "pyproject.toml")
+                )
+            except ValueError:
+                builder._meta = None
+        return builder.ensure_setup_py().as_posix()
