@@ -11,8 +11,7 @@ from typing import TYPE_CHECKING, Any, Iterable, Type, cast
 from urllib.parse import urlparse
 
 import tomlkit
-from pythonfinder import Finder
-from pythonfinder.environment import PYENV_INSTALLED, PYENV_ROOT
+from findpython import Finder
 
 from pdm import termui
 from pdm._types import Source
@@ -36,6 +35,7 @@ from pdm.utils import (
     find_python_in_path,
     get_in_project_venv_python,
     get_venv_like_prefix,
+    normalize_name,
 )
 
 if TYPE_CHECKING:
@@ -46,6 +46,9 @@ if TYPE_CHECKING:
     from pdm.resolver.providers import BaseProvider
 
 
+PYENV_ROOT = os.path.expanduser(os.getenv("PYENV_ROOT", "~/.pyenv"))
+
+
 class Project:
     """Core project class"""
 
@@ -55,7 +58,11 @@ class Project:
     GLOBAL_PROJECT = Path.home() / ".pdm" / "global-project"
 
     def __init__(
-        self, core: Core, root_path: str | Path | None, is_global: bool = False
+        self,
+        core: Core,
+        root_path: str | Path | None,
+        is_global: bool = False,
+        global_config: str | Path | None = None,
     ) -> None:
         self._pyproject: dict | None = None
         self._lockfile: dict | None = None
@@ -63,6 +70,10 @@ class Project:
         self._python: PythonInfo | None = None
         self.core = core
 
+        if global_config is None:
+            global_config = self.GLOBAL_PROJECT.with_name("config.toml")
+        self.global_config = Config(Path(global_config), is_global=True)
+
         if root_path is None:
             root_path = (
                 find_project_root(max_depth=self.global_config["project_max_depth"])
@@ -133,12 +144,7 @@ class Project:
 
     @property
     def scripts(self) -> dict[str, str | dict[str, str]]:
-        return self.tool_settings.get("scripts")  # type: ignore
-
-    @cached_property
-    def global_config(self) -> Config:
-        """Read-and-writable configuration dict for global settings"""
-        return Config(self.GLOBAL_PROJECT.with_name("config.toml"), is_global=True)
+        return self.tool_settings.get("scripts", {})  # type: ignore
 
     @cached_property
     def project_config(self) -> Config:
@@ -159,7 +165,7 @@ class Project:
     @property
     def python_executable(self) -> str:
         """For backward compatibility"""
-        return self.python.executable
+        return str(self.python.executable)
 
     def resolve_interpreter(self) -> PythonInfo:
         """Get the Python interpreter path."""
@@ -168,7 +174,7 @@ class Project:
             saved_path = config["python.path"]
             try:
                 python = PythonInfo.from_path(saved_path)
-                if self.python_requires.contains(str(python.version)):
+                if self.python_requires.contains(str(python.version), True):
                     return python
             except (ValueError, FileNotFoundError):
                 self.project_config.pop("python.path", None)
@@ -181,13 +187,13 @@ class Project:
 
         # Resolve virtual environments from env-vars
         virtual_env = os.getenv("VIRTUAL_ENV", os.getenv("CONDA_PREFIX"))
-        if config["use_venv"] and virtual_env:
+        if config["python.use_venv"] and virtual_env:
             return PythonInfo.from_path(
                 os.path.join(virtual_env, scripts, f"python{suffix}")
             )
 
         for py_version in self.find_interpreters():
-            if self.python_requires.contains(str(py_version.version)):
+            if self.python_requires.contains(str(py_version.version), True):
                 self.python = py_version
                 return py_version
 
@@ -203,9 +209,11 @@ class Project:
             env = GlobalEnvironment(self)
             # Rewrite global project's python requires to be
             # compatible with the exact version
-            env.python_requires = PySpecSet(f"=={self.python.version}")
+            env.python_requires = PySpecSet.equal_to(self.python.version)
             return env
-        if self.config["use_venv"] and get_venv_like_prefix(self.python.executable):
+        if self.config["python.use_venv"] and get_venv_like_prefix(
+            self.python.executable
+        ):
             # Only recognize venv created by python -m venv and virtualenv>20
             return GlobalEnvironment(self)
         return Environment(self)
@@ -355,7 +363,10 @@ class Project:
 
         repository = self.get_repository(cls=self.core.repository_class)
         allow_prereleases = self.allow_prereleases
-        overrides = self.tool_settings.get("overrides", {})
+        overrides = {
+            normalize_name(k): v
+            for k, v in self.tool_settings.get("overrides", {}).items()
+        }
         if strategy != "all" and not self.is_lockfile_compatible():
             self.core.ui.echo(
                 "Updating the whole lock file as it is not compatible with PDM",
@@ -419,9 +430,7 @@ class Project:
     def make_self_candidate(self, editable: bool = True) -> Candidate:
         req = parse_requirement(pip_shims.path_to_url(self.root.as_posix()), editable)
         req.name = self.meta.name
-        return Candidate(
-            req, self.environment, name=self.meta.name, version=self.meta.version
-        )
+        return Candidate(req, name=self.meta.name, version=self.meta.version)
 
     def get_content_hash(self, algo: str = "md5") -> str:
         # Only calculate sources and dependencies groups. Otherwise lock file is
@@ -569,7 +578,7 @@ dependencies = ["pip", "setuptools", "wheel"]
         python: str | Path | None = None
 
         if not python_spec:
-            if config.get("python.use_pyenv", True) and PYENV_INSTALLED:
+            if config.get("python.use_pyenv", True) and os.path.exists(PYENV_ROOT):
                 pyenv_shim = os.path.join(PYENV_ROOT, "shims", "python3")
                 if os.name == "nt":
                     pyenv_shim += ".bat"
@@ -577,7 +586,7 @@ dependencies = ["pip", "setuptools", "wheel"]
                     yield PythonInfo.from_path(pyenv_shim)
                 elif os.path.exists(pyenv_shim.replace("python3", "python")):
                     yield PythonInfo.from_path(pyenv_shim.replace("python3", "python"))
-            if config.get("use_venv"):
+            if config.get("python.use_venv"):
                 python = get_in_project_venv_python(self.root)
                 if python:
                     yield PythonInfo.from_path(python)
@@ -597,9 +606,9 @@ dependencies = ["pip", "setuptools", "wheel"]
                         yield PythonInfo.from_path(python)
                 return
             args = [int(v) for v in python_spec.split(".") if v != ""]
-        finder = Finder()
-        for entry in finder.find_all_python_versions(*args):
-            yield PythonInfo.from_python_version(entry.py_version)
+        finder = Finder(resolve_symlinks=True)
+        for entry in finder.find_all(*args):
+            yield PythonInfo(entry)
         if not python_spec:
             this_python = getattr(sys, "_base_executable", sys.executable)
             yield PythonInfo.from_path(this_python)
