@@ -3,8 +3,8 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Dict, cast
 
 from pdm.models.candidates import Candidate
-from pdm.models.requirements import strip_extras
 from pdm.resolver.providers import BaseProvider
+from pdm.resolver.python import PythonRequirement
 
 if TYPE_CHECKING:
     from resolvelib.resolvers import Resolver
@@ -18,7 +18,7 @@ def resolve(
     requirements: list[Requirement],
     requires_python: PySpecSet,
     max_rounds: int = 10000,
-) -> tuple[dict[str, Candidate], dict[str, list[Requirement]], dict[str, str]]:
+) -> tuple[dict[str, Candidate], dict[str, list[Requirement]]]:
     """Core function to perform the actual resolve process.
     Return a tuple containing 3 items:
 
@@ -26,10 +26,12 @@ def resolve(
         2. A map of resolved dependencies for each dependency group
         3. A map of package descriptions fetched from PyPI source
     """
+    requirements.append(PythonRequirement.from_pyspec_set(requires_python))
     provider = cast(BaseProvider, resolver.provider)
     result = resolver.resolve(requirements, max_rounds)
 
     mapping = cast(Dict[str, Candidate], result.mapping)
+    mapping.pop("python", None)
     for key, candidate in list(result.mapping.items()):
         if key is None:
             continue
@@ -39,14 +41,7 @@ def resolve(
             new_key = provider.identify(candidate)
             mapping[new_key] = mapping.pop(key)
             key = new_key
-        # Root requires_python doesn't participate in the metaset resolving,
-        # now check it!
-        candidate_requires = provider.requires_python_collection[strip_extras(key)[0]]
-        if (requires_python & candidate_requires).is_impossible:
-            # Remove candidates that don't match requires_python constraint
-            del mapping[key]
-        else:
-            candidate.requires_python = str(candidate_requires)
-            candidate.hashes = provider.get_hashes(candidate)
 
-    return mapping, provider.fetched_dependencies, provider.summary_collection
+        candidate.hashes = provider.repository.get_hashes(candidate)
+
+    return mapping, provider.fetched_dependencies
