@@ -72,7 +72,7 @@ def test_sync_only_different(project, working_set, capsys):
     working_set.add_distribution(Distribution("idna", "2.7"))
     actions.do_add(project, packages=["requests"])
     out, _ = capsys.readouterr()
-    assert "4 to add" in out, out
+    assert "3 to add" in out, out
     assert "1 to update" in out
     assert "foo" in working_set
     assert "test-project" in working_set
@@ -81,10 +81,10 @@ def test_sync_only_different(project, working_set, capsys):
 
 @pytest.mark.usefixtures("repository")
 def test_sync_in_sequential_mode(project, working_set, capsys):
-    project.project_config["parallel_install"] = False
+    project.project_config["install.parallel"] = False
     actions.do_add(project, packages=["requests"])
     out, _ = capsys.readouterr()
-    assert "6 to add" in out
+    assert "5 to add" in out
     assert "test-project" in working_set
     assert working_set["chardet"].version == "3.0.4"
 
